const app = getApp()

Page({
  data: {
    qrcodeUrl: '/static/images/qrcode/default_qrcode.png',
    userAvatar: '/static/images/avatar/default_avatar.png',
    userNickname: '推广达人'
  },

  onLoad(options) {
    this.initUserInfo()
  },

  // 初始化用户信息
  initUserInfo() {
    const userInfo = wx.getStorageSync('userInfo')
    console.log('用户信息：', userInfo)
    
    if (userInfo) {
      console.log('二维码地址：', userInfo.qr_code)
      
      this.setData({
        qrcodeUrl: userInfo.qr_code || '/static/images/qrcode/default_qrcode.png',
        userAvatar: userInfo.avatar || '/static/images/avatar/default_avatar.png',
        userNickname: userInfo.nickname || '推广达人'
      }, () => {
        console.log('当前页面数据：', this.data)
      })
    }
  },

  // 预览二维码
  previewQRCode() {
    if (!this.data.qrcodeUrl || this.data.qrcodeUrl === '/static/images/qrcode/default_qrcode.png') {
      wx.showToast({
        title: '二维码未生成',
        icon: 'none'
      })
      return
    }
    
    wx.previewImage({
      urls: [this.data.qrcodeUrl],
      current: this.data.qrcodeUrl
    })
  },

  // 保存二维码
  saveQRCode() {
    if (!this.data.qrcodeUrl || this.data.qrcodeUrl === '/static/images/qrcode/default_qrcode.png') {
      wx.showToast({
        title: '二维码未生成',
        icon: 'none'
      })
      return
    }

    wx.showLoading({
      title: '保存中...'
    })

    wx.downloadFile({
      url: this.data.qrcodeUrl,
      success: (res) => {
        if (res.statusCode === 200) {
          wx.saveImageToPhotosAlbum({
            filePath: res.tempFilePath,
            success: () => {
              wx.showToast({
                title: '保存成功',
                icon: 'success'
              })
            },
            fail: (err) => {
              console.error('保存二维码失败：', err)
              wx.showToast({
                title: '保存失败',
                icon: 'none'
              })
            }
          })
        }
      },
      fail: (err) => {
        console.error('下载二维码失败：', err)
        wx.showToast({
          title: '保存失败',
          icon: 'none'
        })
      },
      complete: () => {
        wx.hideLoading()
      }
    })
  },

  // 分享二维码
  onShareAppMessage() {
    const userInfo = wx.getStorageSync('userInfo')
    return {
      title: '邀请你加入我的团队',
      path: '/pages/index/index?inviter=' + (userInfo ? userInfo.id : ''),
      imageUrl: this.data.qrcodeUrl
    }
  }
})