// pages/index/index.js
const app = getApp()
import { checkNeedLogin, doLogin, getLoginInfo, checkNeedBindInstitution, getUserInfo } from '../../utils/login'
import { request } from '../../utils/request'

Page({
  data: {
    bannerList: [],
    hotGoods: [],
    featuredGoods: [],
    countdown: '',
    timer: null,
    loading: false,
    currentPage: 1,
    pageSize: 10,
    totalPages: 1,
    isLoadingHot: false,
    showAuthModal: false,  // 添加弹窗显示状态
    bindStatus: 0,
    currentGoodsId: null,  // 添加当前商品ID
    currentShopAppid: '', // 当前商品的小店appid
    currentProductId: '', // 当前商品的商品ID
    productPromotionLink: '', // 当前商品的推广链接
    iconZhihu: '/static/images/icon-zhihu.png',
    iconUser: '/static/images/icon-user.png',
    pageNum: 1,
    pageSize: 10,
    hasMore: true,
    showBackTop: false,
    currentProduct: null,
    shareProduct: null,
    isLogin: false, // 添加登录状态
    userInfo: null, // 添加用户信息
    posterUrl: '', // 海报图片URL
    showPosterModal: false, // 控制海报预览模态框显示
  },

  onLoad: function() {
    this.checkLoginStatus();
    this.loadBanners();
    this.loadFeaturedGoods();
    this.getHotGoods();
  },

  onUnload() {
    if (this.data.timer) {
      clearInterval(this.data.timer);
    }
  },

  onShow: function() {
    this.checkLoginStatus()
  },

  // 加载轮播图数据
  async loadBanners() {
    try {
      const res = await request({
        url: '/api/banner/list',
        method: 'GET'
      });
      
      console.log('轮播图接口返回数据：', res);
      
      if (res.errno === '0' && res.rst) {
        console.log('轮播图数据：', res.rst);
        this.setData({
          bannerList: res.rst
        });
      } else {
        console.error('轮播图数据格式错误：', res);
      }
    } catch (error) {
      console.error('加载轮播图失败：', error);
    }
  },

  // 获取热推商品
  getHotGoods() {
    console.log('开始加载热推商品，当前页码：', this.data.currentPage)
    
    if (this.data.isLoadingHot) {
      return
    }

    this.setData({
      isLoadingHot: true
    })

    request({
      url: '/api/goods/list',
      method: 'GET',
      data: {
        page: this.data.currentPage,
        page_size: this.data.pageSize,
        sort: 0
      }
    }).then(res => {
      console.log('热推商品接口返回：', res)
      if (res.rst && res.rst.data && res.rst.data.length > 0) {
        const newGoods = res.rst.data
        const totalPages = res.rst.pageInfo ? parseInt(res.rst.pageInfo.pages || 1) : 1
        
        console.log('分页信息：', {
          currentPage: this.data.currentPage,
          nextPage: this.data.currentPage + 1,
          totalPages,
          dataLength: newGoods.length
        })

        // 格式化商品数据
        const formattedGoods = newGoods.map(item => ({
          id: item.goods_id,
          goods_id: item.goods_id,
          name: item.title,
          price: item.sale_price,
          image: item.head_img_list[0],
          commission: item.total_commission_amount,
          shop_appid: item.shop_appid,  // 添加shop_appid
          product_id: item.product_id   // 添加product_id
        }))

        // 判断是第一页还是加载更多
        const updatedGoods = this.data.currentPage === 1 
          ? formattedGoods 
          : [...this.data.hotGoods, ...formattedGoods]

        this.setData({
          hotGoods: updatedGoods,
          currentPage: this.data.currentPage + 1,
          totalPages: totalPages
        }, () => {
          console.log('数据更新完成，当前状态：', {
            currentPage: this.data.currentPage,
            totalPages: this.data.totalPages,
            goodsLength: this.data.hotGoods.length
          })
          wx.hideLoading()
        })
      }
    }).catch(err => {
      console.error('获取热推商品失败:', err)
      wx.hideLoading()
      wx.showToast({
        title: '获取热推商品失败',
        icon: 'none'
      })
    }).finally(() => {
      this.setData({
        isLoadingHot: false
      })
      wx.stopPullDownRefresh()
    })
  },

  // 加载精选商品
  async loadFeaturedGoods() {
    const res = await request({
      url: '/api/goods/list',
      method: 'GET',
      data: { 
        page: 1, 
        page_size: 4,
        sort: 7  // 选品列表
      }
    });

    if (res && res.rst && res.rst.data) {
      this.setData({
        featuredGoods: res.rst.data.map(item => ({
          id: item.goods_id,
          goods_id: item.goods_id,
          name: item.title,
          price: item.sale_price,
          image: item.head_img || item.head_img_list[0],
          estimatedReturn: (item.total_commission_amount * 0.75).toFixed(1),
          commission: item.total_commission_amount,
          subsidy: (item.total_commission_amount * 0.25).toFixed(1),
          countdown: '',
          recommendReason: item.recommend_reason || '好评如潮，值得推荐！',
          shop_appid: item.shop_appid,  // 添加shop_appid
          product_id: item.product_id   // 添加product_id
        }))
      });
      this.startCountdown();
    } else {
      wx.showToast({
        title: '加载精选商品失败',
        icon: 'none'
      })
    }
  },

  startCountdown: function() {
    const now = new Date();
    const end = new Date(now.getFullYear(), now.getMonth(), now.getDate(), 23, 59, 59);
    
    const timer = setInterval(() => {
      const now = new Date();
      const diff = end - now;
      
      if (diff <= 0) {
        clearInterval(timer);
        this.setData({ countdown: '已结束' });
        return;
      }
      
      const hours = Math.floor(diff / (1000 * 60 * 60)).toString().padStart(2, '0');
      const minutes = Math.floor((diff % (1000 * 60 * 60)) / (1000 * 60)).toString().padStart(2, '0');
      const seconds = Math.floor((diff % (1000 * 60)) / 1000).toString().padStart(2, '0');
      
      const countdownStr = `${hours}:${minutes}:${seconds}`;
      
      // 更新所有精选商品的倒计时
      const updatedGoods = this.data.featuredGoods.map(item => ({
        ...item,
        countdown: countdownStr
      }));
      
      this.setData({
        featuredGoods: updatedGoods
      });
    }, 1000);
    
    this.setData({ timer });
  },

  // 跳转到商品详情
  navigateToDetail(e) {
    const goodsId = e.currentTarget.dataset.goodsId;
    console.log('1. 获取到的商品ID:', goodsId);
    
    if (!goodsId) {
      console.error('商品ID不存在');
      return;
    }

    // 从当前页面数据中查找商品信息
    const product = [...this.data.hotGoods, ...this.data.featuredGoods].find(item => item.goods_id === goodsId);
    console.log('2. 当前页面数据:', {
      hotGoods: this.data.hotGoods,
      featuredGoods: this.data.featuredGoods
    });
    console.log('3. 找到的商品信息:', product);
    
    if (!product) {
      console.error('未找到商品信息');
      return;
    }

    // 获取bindStatus
    const bindStatus = wx.getStorageSync('bindStatus') || 0;
    console.log('4. 当前bindStatus:', bindStatus);

    // 获取用户信息
    const userInfo = wx.getStorageSync('userInfo');
    console.log('5. 用户信息:', userInfo);

    // 先设置基本信息
    const setData = {
      showAuthModal: true,
      bindStatus,
      currentProduct: product,
      currentGoodsId: goodsId,
      currentShopAppid: product.shop_appid,  // 直接从商品数据中获取
      currentProductId: product.product_id,   // 直接从商品数据中获取
      productPromotionLink: ''
    };

    console.log('6. 商品基本信息:', {
      shop_appid: product.shop_appid,
      product_id: product.product_id
    });

    // 获取推广链接
    request({
      url: '/api/goods/productPromotionLink',
      method: 'POST',
      data: {
        goods_id: goodsId,
        user_id: userInfo ? userInfo.id : '',
        sharer_appid: userInfo ? userInfo.sharer_appid : ''
      }
    }).then(res => {
      console.log('7. 推广链接API返回:', res);
      if (res.errno === '0' && res.rst) {
        setData.productPromotionLink = res.rst.product_promotion_link || '';
        console.log('8. 最终设置的数据:', setData);
        
        this.setData(setData, () => {
          console.log('9. 数据设置完成，当前状态：', {
            showAuthModal: this.data.showAuthModal,
            currentShopAppid: this.data.currentShopAppid,
            currentProductId: this.data.currentProductId,
            productPromotionLink: this.data.productPromotionLink
          });
        });
      } else {
        console.error('10. 获取推广链接失败:', res);
        wx.showToast({
          title: '获取商品信息失败',
          icon: 'none'
        });
      }
    }).catch(err => {
      console.error('11. 获取推广链接请求失败:', err);
      wx.showToast({
        title: '获取商品信息失败',
        icon: 'none'
      });
    });
  },

  // 直接购买商品
  buyDirectly(e) {
    const { productId, appid } = e.currentTarget.dataset;
    if (!productId || !appid) {
      console.log('缺少商品信息', { productId, appid });
      return;
    }
    
    wx.navigateToMiniProgram({
      appId: appid,
      path: `pages/product/detail?productId=${productId}`,
      success: () => {
        console.log('跳转成功', { productId, appid });
        this.hideAuthModal();
      },
      fail: (err) => {
        console.error('跳转失败', err);
        wx.showToast({
          title: '打开失败，请重试',
          icon: 'none',
          duration: 2000
        });
      }
    });
  },

  // 分享商品
  async onShareProduct() {
    console.log('[分享商品] 开始分享商品');
    await this.generatePoster();
  },

  // 跳转到商品详情页
  navigateToGoodsDetail(goodsId) {
    wx.navigateTo({
      url: `/pages/goods/detail/index?id=${goodsId}`,
      fail: (err) => {
        console.error('跳转商品详情失败:', err);
        wx.showToast({
          title: '跳转失败',
          icon: 'none'
        });
      }
    });
  },

  // 跳转到搜索页面
  navigateToSearch() {
    wx.navigateTo({
      url: '/pages/search/index',
      fail: (err) => {
        console.error('跳转搜索页面失败:', err);
        wx.showToast({
          title: '跳转失败',
          icon: 'none'
        });
      }
    });
  },

  onBannerTap(e) {
    const url = e.currentTarget.dataset.url;
    if (url) {
      wx.navigateTo({
        url,
        fail: (err) => {
          console.error('跳转页面失败:', err);
          wx.showToast({
            title: '跳转失败',
            icon: 'none'
          });
        }
      });
    }
  },

  // 监听页面滚动
  onPageScroll: function(e) {
    // 滚动超过一屏显示回到顶部按钮
    this.setData({
      showBackTop: e.scrollTop > wx.getSystemInfoSync().windowHeight
    })
  },

  // 回到顶部
  backToTop: function() {
    wx.pageScrollTo({
      scrollTop: 0,
      duration: 300
    })
  },

  // 重置并重新加载
  resetAndReload() {
    this.setData({
      currentPage: 1,
      totalPages: 1,
      hotGoods: []
    }, () => {
      this.getHotGoods()
    })
  },

  // 下拉刷新
  onPullDownRefresh: function() {
    this.resetAndReload()
  },

  // 上拉加载更多
  onReachBottom: function() {
    console.log('触发上拉加载', {
      currentPage: this.data.currentPage,
      totalPages: this.data.totalPages,
      isLoading: this.data.isLoadingHot
    })
    
    if (!this.data.isLoadingHot) {
      wx.showLoading({
        title: '加载中...',
      })
      this.getHotGoods()
    }
  },

  // 阻止事件冒泡
  preventTap() {
    // 空函数，仅用于阻止事件冒泡
  },

  // 点击授权按钮
  onAuthClick() {
    if (!this.data.isLogin) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      })
      return
    }

    const userInfo = wx.getStorageSync('userInfo')
    if (!userInfo) {
      wx.showToast({
        title: '获取用户信息失败',
        icon: 'none'
      })
      return
    }

    const businessType = userInfo.bind_business_type
    const queryString = userInfo.bind_query_string
    const commissionType = userInfo.commission_type
    const commissionRatio = userInfo.commission_ratio
    const headSupplierAppid = userInfo.head_supplier_appid

    wx.openBusinessView({
      businessType: businessType,
      queryString: queryString,
      extraData: {
        commissionType: commissionType,
        commissionRatio: commissionRatio,
        headSupplierAppid: headSupplierAppid
      },
      success: (res) => {
        console.log('绑定机构成功', res)
        wx.setStorageSync('bindStatus', 1)
        this.setData({ 
          bindStatus: 1,
          showAuthModal: false  // 绑定成功后关闭弹窗
        })
        // 重新获取用户信息
        this.getUserInfo()
      },
      fail: (err) => {
        console.error('绑定机构失败', err)
        wx.showToast({
          title: '绑定失败',
          icon: 'none'
        })
      }
    })
  },

  // 获取用户信息
  async getUserInfo() {
    try {
      const userInfo = wx.getStorageSync('userInfo')
      console.log('当前userInfo:', userInfo)
      this.setData({ 
        userInfo,
        isLogin: true // 设置登录状态
      })
    } catch (err) {
      console.error('获取用户信息失败:', err)
    }
  },

  // 隐藏授权弹窗
  hideAuthModal() {
    console.log('14. 隐藏弹窗前的状态:', {
      currentShopAppid: this.data.currentShopAppid,
      currentProductId: this.data.currentProductId,
      productPromotionLink: this.data.productPromotionLink
    });
    
    this.setData({
      showAuthModal: false,
      currentProduct: null,
      currentGoodsId: null,
      currentShopAppid: '',
      currentProductId: '',
      productPromotionLink: ''
    });
  },

  // store-product组件事件处理
  onStoreProductEnterError(e) {
    console.error('12. 进入商品失败，错误详情:', e.detail);
    console.log('13. 当前组件状态:', {
      currentShopAppid: this.data.currentShopAppid,
      currentProductId: this.data.currentProductId,
      productPromotionLink: this.data.productPromotionLink
    });
    
    wx.showToast({
      title: '进入商品失败',
      icon: 'none'
    });
  },

  // store-product组件进入失败处理
  onStoreProductEnterError(e) {
    console.error('进入商品失败', e.detail);
    const { error } = e.detail;
    wx.showToast({
      title: error?.message || '打开商品失败',
      icon: 'none',
      duration: 2000
    });
  },

  // 打开商品详情
  openProduct() {
    const { currentProductId, currentShopAppid } = this.data;
    if (!currentProductId || !currentShopAppid) {
      console.log('缺少商品信息', { currentProductId, currentShopAppid });
      return;
    }
    
    wx.navigateToMiniProgram({
      appId: currentShopAppid,
      path: `pages/product/detail?productId=${currentProductId}`,
      success: () => {
        console.log('跳转成功', { currentProductId, currentShopAppid });
        this.hideAuthModal();
      },
      fail: (err) => {
        console.error('跳转失败', err);
        wx.showToast({
          title: '打开失败，请重试',
          icon: 'none',
          duration: 2000
        });
      }
    });
  },

  // 跳转到更多精选
  goToMoreGoods() {
    wx.navigateTo({
      url: '/pages/goods/list/index'
    })
  },

  // 检查登录状态
  async checkLoginStatus() {
    console.log('检查登录状态')
    if (checkNeedLogin()) {
      try {
        await doLogin()
        this.setData({ isLogin: true })
        this.getUserInfo()
      } catch (err) {
        console.error('登录失败:', err)
        this.setData({ isLogin: false })
      }
    } else {
      this.setData({ isLogin: true })
      this.getUserInfo()
    }

    // 检查是否需要绑定机构
    const bindStatus = wx.getStorageSync('bindStatus')
    console.log('当前bindStatus:', bindStatus)
    const needBind = checkNeedBindInstitution()
    console.log('是否需要绑定机构:', needBind)
    getUserInfo()
    this.setData({ bindStatus: bindStatus || 0 })
  },

  // 获取商品二维码
  async getShareQrCode(goodsId) {
    try {
      console.log('[二维码生成] 开始获取, 商品ID:', goodsId);
      
      const userInfo = getLoginInfo();
      console.log('[二维码生成] 用户信息:', userInfo);

      if (!goodsId) {
        throw new Error('商品ID不能为空');
      }

      const res = await request({
        url: '/api/goods/shareQrCode',
        method: 'POST',
        data: {
          goods_id: goodsId,
          user_id: userInfo ? userInfo.id : '',
          sharer_appid: userInfo ? userInfo.sharer_appid : ''
        }
      });

      console.log('[二维码生成] 接口返回:', res);

      if (res.errno === 0 || res.errno === '0') {  // 兼容字符串和数字类型
        if (res.rst && res.rst.qrcode_url) {
          console.log('[二维码生成] 成功获取URL:', res.rst.qrcode_url);
          return res.rst.qrcode_url;
        } else {
          console.error('[二维码生成] 返回数据格式错误:', res);
          throw new Error('二维码数据格式错误');
        }
      } else {
        console.error('[二维码生成] 接口返回错误:', res);
        throw new Error(res.err || '获取二维码失败');
      }
    } catch (error) {
      console.error('[二维码生成] 发生错误:', error);
      wx.showToast({
        title: '获取二维码失败：' + (error.message || '未知错误'),
        icon: 'none',
        duration: 2000
      });
      throw error; // 向上抛出错误，让调用者知道发生了错误
    }
  },

  // 生成海报
  async generatePoster() {
    try {
      wx.showLoading({
        title: '生成海报中...',
        mask: true
      });
      
      const { currentProduct, currentProductId, currentGoodsId } = this.data;
      console.log('[海报生成] 商品信息:', { currentProduct, currentProductId, currentGoodsId });
      
      if (!currentProduct || !currentProductId) {
        throw new Error('商品信息不完整');
      }

      // 获取二维码
      console.log('[海报生成] 开始获取商品二维码');
      const qrcodeUrl = await this.getShareQrCode(currentGoodsId);
      if (!qrcodeUrl) {
        console.error('[海报生成] 获取二维码失败');
        throw new Error('获取二维码失败');
      }
      console.log('[海报生成] 获取二维码成功:', qrcodeUrl);

      // 检查商品图片
      console.log('[海报生成] 开始下载商品图片');
      const productImage = await new Promise((resolve, reject) => {
        wx.getImageInfo({
          src: currentProduct.image,
          success: res => {
            console.log('[海报生成] 商品图片下载成功:', res.path);
            resolve(res);
          },
          fail: err => {
            console.error('[海报生成] 商品图片下载失败:', err);
            reject(err);
          }
        });
      });

      // 下载二维码图片
      console.log('[海报生成] 开始下载二维码图片');
      const qrcodeImage = await new Promise((resolve, reject) => {
        wx.getImageInfo({
          src: qrcodeUrl,
          success: res => {
            console.log('[海报生成] 二维码图片下载成功:', res.path);
            resolve(res);
          },
          fail: err => {
            console.error('[海报生成] 二维码图片下载失败:', err);
            reject(err);
          }
        });
      });

      console.log('[海报生成] 开始绘制海报');
      const ctx = wx.createCanvasContext('posterCanvas');
      
      // 绘制背景
      ctx.setFillStyle('#FF5B4C');  // 设置整个画布背景为橙红色
      ctx.fillRect(0, 0, 750, 1500);

      // 绘制内层白色圆角背景
      ctx.save();
      ctx.beginPath();
      const radius = 20;
      // 白色区域的位置和大小（上下边距80px，左右边距40px）
      ctx.moveTo(40 + radius, 80);
      ctx.lineTo(710 - radius, 80);
      ctx.arcTo(710, 80, 710, 80 + radius, radius);
      ctx.lineTo(710, 1420 - radius);  // 1500 - 80
      ctx.arcTo(710, 1420, 710 - radius, 1420, radius);
      ctx.lineTo(40 + radius, 1420);
      ctx.arcTo(40, 1420, 40, 1420 - radius, radius);
      ctx.lineTo(40, 80 + radius);
      ctx.arcTo(40, 80, 40 + radius, 80, radius);
      ctx.closePath();
      ctx.setFillStyle('#ffffff');
      ctx.fill();
      ctx.restore();

      // 绘制顶部装饰
      // 左侧横线
      ctx.setStrokeStyle('#FF5B4C');
      ctx.setLineWidth(2);  // 加粗线条
      ctx.moveTo(260, 180);  // 下移装饰线
      ctx.lineTo(350, 180);
      ctx.stroke();
      // 右侧横线
      ctx.moveTo(400, 180);  // 线条右移
      ctx.lineTo(490, 180);
      ctx.stroke();
      // 蝴蝶结（简化版）
      ctx.beginPath();
      ctx.arc(375, 180, 20, 0, 2 * Math.PI);  // 增大圆圈
      ctx.setFillStyle('#FF5B4C');
      ctx.fill();

      // 绘制商品标题
      ctx.setFillStyle('#333333');
      ctx.setFontSize(32);  // 放大标题字号
      const title = currentProduct.name;
      const titleLines = this.splitText(ctx, title, 630);
      titleLines.slice(0, 2).forEach((line, index) => {
        ctx.fillText(line, 60, 280 + index * 45);  // 增加行间距
      });

      // 绘制价格
      ctx.setFillStyle('#FF5B4C');
      ctx.setFontSize(36);  // 放大价格符号
      ctx.fillText('¥', 60, 400);  // 下移价格
      ctx.setFontSize(48);  // 放大价格数字
      ctx.fillText(currentProduct.price, 90, 400);

      // 绘制商品图片
      ctx.drawImage(productImage.path, 60, 460, 630, 650);  // 下移并适当增加高度

      // 绘制底部信息
      ctx.drawImage(qrcodeImage.path, 480, 1200, 180, 180);  // 下移二维码
      
      // 绘制微信小店icon和文字
      // 加载小店icon
      await new Promise((resolve, reject) => {
        const iconPath = 'https://kx-wechat-shop.oss-cn-beijing.aliyuncs.com/2025/02/17/wechat_shop.png';  // 使用相对路径
        console.log('[海报生成] 尝试加载小店icon:', iconPath);
        wx.getImageInfo({
          src: iconPath,
          success: res => {
            console.log('[海报生成] 加载小店icon成功', res);
            ctx.drawImage(res.path, 80, 1260, 40, 40);
            ctx.setFillStyle('#666666');
            ctx.setFontSize(28);
            ctx.fillText('微信小店', 125, 1290);
            ctx.setFillStyle('#999999');
            ctx.setFontSize(26);
            ctx.fillText('微信扫一扫购买', 80, 1330);
            resolve();
          },
          fail: err => {
            console.error('[海报生成] 加载小店icon失败', err);
            // 即使加载失败也继续绘制文字
            ctx.setFillStyle('#666666');
            ctx.setFontSize(28);
            ctx.fillText('微信小店', 120, 1290);
            ctx.setFillStyle('#999999');
            ctx.setFontSize(26);
            ctx.fillText('微信扫一扫购买', 120, 1330);
            resolve();
          }
        });
      });
      
      console.log('[海报生成] 开始导出画布');
      const res = await new Promise((resolve, reject) => {
        ctx.draw(false, () => {
          console.log('[海报生成] 画布绘制完成，准备导出图片');
          wx.canvasToTempFilePath({
            canvasId: 'posterCanvas',
            success: res => {
              console.log('[海报生成] 海报导出成功:', res.tempFilePath);
              resolve(res);
            },
            fail: err => {
              console.error('[海报生成] 海报导出失败:', err);
              reject(err);
            }
          });
        });
      });

      // 设置海报URL和显示预览模态框
      console.log('[海报生成] 显示预览模态框');
      this.setData({
        posterUrl: res.tempFilePath,
        showPosterModal: true
      }, () => {
        // 显示分享菜单
        wx.showShareImageMenu({
          path: res.tempFilePath,
          complete: () => {
            // 无论用户是分享还是取消，都关闭海报预览
            this.setData({
              showPosterModal: false
            })
          }
        })
      })
      
      wx.hideLoading();
    } catch (error) {
      console.error('[海报生成] 发生错误:', error);
      wx.hideLoading();
      wx.showToast({
        title: '生成海报失败',
        icon: 'none'
      });
    }
  },

  // 文本分行处理
  splitText(ctx, text, maxWidth) {
    console.log('[文本处理] 开始分行处理:', { text, maxWidth });
    const chars = text.split('');
    const lines = [];
    let tempLine = '';
    
    chars.forEach((char) => {
      const testLine = tempLine + char;
      const metrics = ctx.measureText(testLine);
      if (metrics.width > maxWidth) {
        console.log('[文本处理] 当前行宽度超出，添加新行:', tempLine);
        lines.push(tempLine);
        tempLine = char;
      } else {
        tempLine = testLine;
      }
    });
    
    if (tempLine) {
      console.log('[文本处理] 添加最后一行:', tempLine);
      lines.push(tempLine);
    }
    
    console.log('[文本处理] 分行结果:', lines);
    return lines;
  },

  // 保存海报到相册
  async savePosterToAlbum() {
    console.log('[保存海报] 开始保存海报到相册');
    try {
      wx.showLoading({
        title: '保存中...',
        mask: true
      });
      
      console.log('[保存海报] 海报路径:', this.data.posterUrl);
      const res = await wx.saveImageToPhotosAlbum({
        filePath: this.data.posterUrl
      });
      
      console.log('[保存海报] 保存成功:', res);
      wx.hideLoading();
      wx.showToast({
        title: '保存成功',
        icon: 'success'
      });
      
      // 关闭预览模态框
      console.log('[保存海报] 关闭预览模态框');
      this.setData({
        showPosterModal: false
      });
    } catch (error) {
      console.error('[保存海报] 保存失败:', error);
      wx.hideLoading();
      wx.showToast({
        title: '保存失败',
        icon: 'none'
      });
    }
  },

  // 关闭海报预览
  closePosterModal() {
    console.log('[海报预览] 关闭预览模态框');
    this.setData({
      showPosterModal: false
    });
  },

  // 处理海报图片加载完成
  onPosterImageLoad(e) {
    console.log('[海报预览] 图片加载完成:', {
      width: e.detail.width,
      height: e.detail.height
    });
  },
});
