import { request } from '../../utils/request'

Page({
  data: {
    qrcodeUrl: '/static/images/qrcode/default_qrcode.png',
    userAvatar: '/static/images/avatar/default_avatar.png',
    userNickname: '推广达人',
    userInfo: {
      avatarUrl: '',
      nickName: '',
      distributionId: ''
    }
  },

  onLoad(options) {
    this.initUserInfo()
    this.getUserInfo()
  },

  // 初始化用户信息
  initUserInfo() {
    const userInfo = wx.getStorageSync('userInfo')
    console.log('用户信息：', userInfo)
    
    if (userInfo) {
      this.setData({
        userAvatar: userInfo.avatar || '/static/images/avatar/default_avatar.png',
        userNickname: userInfo.nickname || '推广达人'
      })

      // 如果没有二维码，则调用接口获取
      if (!userInfo.qr_code) {
        this.getQRCode(userInfo.id)
      } else {
        this.setData({
          qrcodeUrl: userInfo.qr_code
        })
      }
    } else {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      })
    }
  },

  // 获取推广二维码
  getQRCode(userId) {
    wx.showLoading({
      title: '获取二维码...'
    })

    request({
      url: '/api/user/qrCode',
      method: 'GET',
      data: {
        user_id: userId
      }
    })
      .then(res => {
        console.log('获取二维码结果：', res)
        if (res.errno === '0' && res.rst && res.rst.qr_code) {
          this.setData({
            qrcodeUrl: res.rst.qr_code
          })

          // 更新本地存储的用户信息
          const userInfo = wx.getStorageSync('userInfo')
          userInfo.qr_code = res.rst.qr_code
        } else {
          wx.showToast({
            title: '获取二维码失败',
            icon: 'none'
          })
        }
      })
      .catch(err => {
        console.error('获取二维码失败：', err)
        wx.showToast({
          title: '获取二维码失败',
          icon: 'none'
        })
      })
      .finally(() => {
        wx.hideLoading()
      })
  },

  // 预览二维码
  previewQRCode() {
    if (!this.data.qrcodeUrl || this.data.qrcodeUrl === '/static/images/qrcode/default_qrcode.png') {
      wx.showToast({
        title: '二维码未生成',
        icon: 'none'
      })
      return
    }
    
    wx.previewImage({
      urls: [this.data.qrcodeUrl],
      current: this.data.qrcodeUrl
    })
  },

  // 分享二维码
  shareQRCode() {
    if (!this.data.qrcodeUrl || this.data.qrcodeUrl === '/static/images/qrcode/default_qrcode.png') {
      wx.showToast({
        title: '二维码未生成',
        icon: 'none'
      })
      return
    }

    wx.downloadFile({
      url: this.data.qrcodeUrl,
      success: (res) => {
        wx.showShareImageMenu({
          path: res.tempFilePath
        })
      }
    })
  },

  // 获取用户信息
  getUserInfo() {
    const userInfo = wx.getStorageSync('userInfo')
    if (userInfo) {
      this.setData({
        userInfo: {
          ...userInfo,
          distributionId: wx.getStorageSync('distributionId') || ''
        }
      })
    } else {
      wx.getUserProfile({
        desc: '用于展示推广二维码',
        success: (res) => {
          const userInfo = res.userInfo
          if(userInfo) {
            wx.setStorageSync('userInfo', userInfo)
          }
          this.setData({
            userInfo: {
              ...userInfo,
              distributionId: wx.getStorageSync('distributionId') || ''
            }
          })
        }
      })
    }
  },

  // 分享小程序
  onShareAppMessage() {
    return {
      title: `${this.data.userNickname}邀请你加入团队`,
      path: `/pages/index/index?inviter_id=${this.data.userInfo.distributionId}`,
      imageUrl: this.data.qrcodeUrl
    }
  }
})