import { request } from '../../utils/request'

Page({
  data: {
    currentDate: '',
    teamData: {
      totalMembers: 0,
      totalCommission: '0.00',
      totalOrders: 0
    },
    memberList: [],
    loading: false,
    page: 1,
    pageSize: 20,
    hasMore: true
  },

  onLoad() {
    this.setCurrentDate();
    this.getTeamOverview();
    this.getTeamMembers();
  },

  // 设置当前日期
  setCurrentDate() {
    const date = new Date();
    const year = date.getFullYear();
    const month = date.getMonth() + 1;
    const day = date.getDate();
    this.setData({
      currentDate: `${year}年${month}月${day}日`
    });
  },

  // 获取团队概览数据
  getTeamOverview() {
    const userInfo = wx.getStorageSync('userInfo')
    if (!userInfo || !userInfo.id) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      });
      return;
    }

    wx.showLoading({
      title: '加载中'
    });

    request({
      url: '/api/team/condition',
      method: 'GET',
      data: {
        user_id: userInfo.id
      }
    })
      .then(res => {
        console.log('团队概览数据：', res);
        if (res.errno === '0' && res.rst && res.rst) {
          const overview = res.rst;
          console.log('设置数据：', {
            totalMembers: overview.total_members,
            totalCommission: overview.total_rebate,
            totalOrders: overview.total_orders
          });
          this.setData({
            teamData: {
              totalMembers: overview.total_members || 0,
              totalCommission: overview.total_rebate ? overview.total_rebate.toFixed(2) : '0.00',
              totalOrders: overview.total_orders || 0
            }
          });
        } else if (res.errno !== '0') {
          wx.showToast({
            title: res.err || '获取数据失败',
            icon: 'none'
          });
        }
      })
      .catch(err => {
        console.error('获取团队概览失败：', err);
        wx.showToast({
          title: '网络错误，请重试',
          icon: 'none'
        });
      })
      .finally(() => {
        wx.hideLoading();
      });
  },

  // 获取团队成员列表
  getTeamMembers() {
    if (!this.data.hasMore || this.data.loading) return;

    const userInfo = wx.getStorageSync('userInfo')
    if (!userInfo || !userInfo.id) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      });
      return;
    }

    this.setData({ loading: true });

    request({
      url: '/api/team/promoterList',
      method: 'GET',
      data: {
        user_id: userInfo.id,
        page: this.data.page,
        page_size: this.data.pageSize
      }
    })
      .then(res => {
        console.log('团队成员列表：', res);
        if (res.errno === '0' && res.rst) {
          const { list = [], total = 0 } = res.rst;
          
          // 格式化数据
          const formattedList = list.map(item => ({
            id: item.id,
            avatar: item.avatar || '/static/images/default-avatar.png',
            nickname: item.nickname || '未设置昵称',
            joinTime: item.join_time.split(' ')[0], // 只显示日期部分
            orderCount: item.total_orders || 0,
            commission: item.total_rebate ? item.total_rebate.toFixed(2) : '0.00'
          }));

          this.setData({
            memberList: this.data.page === 1 ? formattedList : this.data.memberList.concat(formattedList),
            hasMore: this.data.page * this.data.pageSize < total,
            page: this.data.hasMore ? this.data.page + 1 : this.data.page
          });
        }
      })
      .catch(err => {
        console.error('获取团队成员列表失败：', err);
        wx.showToast({
          title: '获取成员列表失败',
          icon: 'none'
        });
      })
      .finally(() => {
        this.setData({ loading: false });
      });
  },

  // 下拉加载更多
  loadMore() {
    this.getTeamMembers();
  },

  // 分享按钮点击事件
  onShare() {
    wx.showShareMenu({
      withShareTicket: true,
      menus: ['shareAppMessage', 'shareTimeline']
    });
  },

  // 分享给朋友
  onShareAppMessage() {
    return {
      title: '邀请你加入我的团队',
      path: '/pages/index/index?inviter=' + wx.getStorageSync('userInfo').id,
      imageUrl: '/static/images/share-team.png'
    };
  },

  // 分享到朋友圈
  onShareTimeline() {
    return {
      title: '邀请你加入我的团队',
      query: 'inviter=' + wx.getStorageSync('userInfo').id,
      imageUrl: '/static/images/share-team.png'
    };
  }
});