// pages/user/index.js
const app = getApp()
import { checkNeedLogin, doLogin, getLoginInfo, checkNeedBindInstitution, getUserInfo } from '../../utils/login'
import { request, uploadFile } from '../../utils/request'

Page({
  data: {
    userInfo: null,
    isLogin: false,
    needBind: false,
    earnings: {
      today: '0.00',
      month: '0.00',
      total: '0.00',
      balance: '0.00',
      waitSettle: '0.00'
    },
    showEditPopup: false,
    tempUserInfo: {
      avatar: '',
      nickname: ''
    }
  },

  onLoad() {
    this.checkLoginStatus()
  },

  onShow() {
    this.checkLoginStatus()
    this.getEarnings() // 每次显示页面时获取最新的收益数据
  },

  // 检查登录状态
  async checkLoginStatus() {
    console.log('检查登录状态')
    if (checkNeedLogin()) {
      try {
        await doLogin()
        this.setData({ isLogin: true })
        this.getUserInfo()
      } catch (err) {
        console.error('登录失败:', err)
        this.setData({ isLogin: false })
      }
    } else {
      this.setData({ isLogin: true })
      this.getUserInfo()
    }

    // 检查是否需要绑定机构
    const needBind = checkNeedBindInstitution()
    console.log('是否需要绑定机构:', needBind)
    this.setData({ needBind })
  },

  // 获取用户信息
  async getUserInfo() {
    try {
      const userInfo = wx.getStorageSync('userInfo')
      console.log('当前userInfo:', userInfo)
      this.setData({ userInfo })
    } catch (err) {
      console.error('获取用户信息失败:', err)
    }
  },

  // 获取收益信息
  async getEarnings() {
    if (!this.data.isLogin) return;

    const userInfo = wx.getStorageSync('userInfo');
    if (!userInfo) return;

    try {
      console.log('开始请求收益信息...')
      const res = await request({
        url: '/api/user/myEarnings',
        method: 'GET',
        data: {
          user_id: userInfo.id
        }
      });

      console.log('收益信息接口返回数据:', res.rst)

      if (res.rst) {
        // 构造earnings_data对象
        const earningsData = {
          this_day_forecast_income: res.rst.this_day_forecast_income || '0.00',
          this_month_forecast_income: res.rst.this_month_forecast_income || '0.00',
          all_settlement_income: res.rst.all_settlement_income || '0.00',
          account_balance: res.rst.account_balance || '0.00',
          wait_settlement_income: res.rst.wait_settlement_income || '0.00'
        }

        // 更新storage中的earnings_data
        console.log('准备更新earnings_data到storage:', earningsData)
        wx.setStorageSync('earnings_data', earningsData)

        // 检查storage是否更新成功
        const savedData = wx.getStorageSync('earnings_data')
        console.log('storage中的earnings_data:', savedData)

        // 更新页面显示数据
        this.setData({
          earnings: {
            today: earningsData.this_day_forecast_income,
            month: earningsData.this_month_forecast_income,
            total: earningsData.all_settlement_income,
            balance: earningsData.account_balance,
            waitSettle: earningsData.wait_settlement_income
          }
        });
      }
    } catch (err) {
      console.error('获取收益信息失败:', err);
      wx.showToast({
        title: '获取收益信息失败',
        icon: 'none'
      });
    }
  },

  // 显示编辑用户信息弹窗
  showEditUserInfo() {
    if (!this.data.isLogin) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      })
      return
    }
    this.setData({
      showEditPopup: true,
      tempUserInfo: {
        avatar: this.data.userInfo?.avatar || '',
        nickname: this.data.userInfo?.nickname || ''
      }
    })
  },

  // 隐藏编辑用户信息弹窗
  hideEditUserInfo() {
    this.setData({
      showEditPopup: false
    })
  },

  // 处理头像加载错误
  handleAvatarError(e) {
    console.error('头像加载失败:', e)
    // 如果是临时头像加载失败，使用默认头像
    if (this.data.tempUserInfo.avatar && this.data.tempUserInfo.avatar.includes('tmp')) {
      this.setData({
        'tempUserInfo.avatar': '/static/images/default-avatar.png'
      })
    }
    // 如果是用户头像加载失败，使用默认头像
    else if (this.data.userInfo && this.data.userInfo.avatar) {
      this.setData({
        'userInfo.avatar': '/static/images/default-avatar.png'
      })
    }
  },

  // 选择头像回调
  onChooseAvatar(e) {
    console.log('触发头像选择回调')
    console.log('回调数据:', e)

    if (!e || !e.detail || !e.detail.avatarUrl) {
      console.error('未获取到头像URL')
      wx.showToast({
        title: '获取头像失败',
        icon: 'none'
      })
      return
    }

    const tempFilePath = e.detail.avatarUrl
    console.log('选择的头像临时文件:', tempFilePath)

    // 先更新预览
    this.setData({
      'tempUserInfo.avatar': tempFilePath
    })

    // 立即上传文件
    wx.showLoading({
      title: '上传中...',
      mask: true
    })

    console.log('准备调用uploadFile...')
    
    // 直接使用wx.uploadFile
    const token = wx.getStorageSync('token')
    wx.uploadFile({
      url: 'https://shop.wenxingshuju.com/api/file/upload',
      filePath: tempFilePath,
      name: 'file',
      header: {
        'Authorization': token ? `Bearer ${token}` : ''
      },
      formData: {},
      success: (res) => {
        console.log('上传成功，原始返回:', res)
        if (res.statusCode === 200) {
          try {
            const data = JSON.parse(res.data)
            console.log('解析后的数据:', data)
            if (data.errno === '0' && data.rst && data.rst.url) {
              // 检查返回的URL是否包含 http 或 https
              let avatarUrl = data.rst.url
              if (!avatarUrl.startsWith('http://') && !avatarUrl.startsWith('https://')) {
                avatarUrl = 'https:' + avatarUrl
              }
              
              this.setData({
                'tempUserInfo.avatar': avatarUrl
              }, () => {
                console.log('头像已更新为:', avatarUrl)
                wx.hideLoading()
                wx.showToast({
                  title: '头像上传成功',
                  icon: 'success'
                })
              })
            } else {
              throw new Error(data.errmsg || '上传失败')
            }
          } catch (err) {
            console.error('解析返回数据失败:', err)
            this.handleUploadError(err)
          }
        } else {
          this.handleUploadError(new Error('上传失败，状态码：' + res.statusCode))
        }
      },
      fail: (err) => {
        console.error('上传请求失败:', err)
        this.handleUploadError(err)
      }
    })
  },

  // 处理上传错误
  handleUploadError(err) {
    console.error('头像上传失败:', err)
    wx.hideLoading()
    wx.showToast({
      title: err.message || '头像上传失败',
      icon: 'none'
    })
    // 上传失败，恢复原来的头像
    this.setData({
      'tempUserInfo.avatar': this.data.userInfo?.avatar || ''
    })
  },

  // 昵称输入回调
  onInputNickname(e) {
    this.setData({
      'tempUserInfo.nickname': e.detail.value
    })
  },

  // 保存用户信息
  async saveUserInfo() {
    const { avatar, nickname } = this.data.tempUserInfo
    console.log('准备保存的用户信息:', { avatar, nickname })
    
    if (!avatar || !nickname) {
      wx.showToast({
        title: '请完善信息',
        icon: 'none'
      })
      return
    }

    // 如果头像是临时文件地址，说明还没上传完成
    if (avatar.startsWith('http://tmp/') || avatar.startsWith('wxfile://tmp/')) {
      wx.showToast({
        title: '头像正在上传，请稍候',
        icon: 'none'
      })
      return
    }

    try {
      const userInfo = getLoginInfo()
      const res = await request({
        url: '/api/promoter/updateInfo',
        method: 'POST',
        data: {
          user_id: userInfo.id,
          avatar,
          nickname
        }
      })

      if (res.errno === '0') {
        // 更新本地存储的用户信息
        const localUserInfo = wx.getStorageSync('userInfo')
        localUserInfo.avatar = avatar
        localUserInfo.nickname = nickname
        wx.setStorageSync('userInfo', localUserInfo)

        // 更新页面数据
        this.setData({
          userInfo: localUserInfo,
          showEditPopup: false
        })

        wx.showToast({
          title: '更新成功',
          icon: 'success'
        })
      } else {
        throw new Error(res.errmsg || '更新失败')
      }
    } catch (err) {
      console.error('保存用户信息失败:', err)
      wx.showToast({
        title: err.message || '更新失败',
        icon: 'none'
      })
    }
  },

  // 导航到分销中心
  navigateToDistribution() {
    wx.navigateTo({
      url: '/pages/distribution/index'
    })
  },

  // 导航到推广订单
  navigateToOrder() {
    wx.navigateTo({
      url: '/pages/order/list'
    })
  },

  // 导航到我的团队
  navigateToTeam() {
    wx.navigateTo({
      url: '/pages/team/index'
    })
  },

  // 导航到提现管理
  navigateToWithdraw() {
    wx.navigateTo({
      url: '/pages/income/withdraw'
    })
  },

  // 导航到收款账户
  navigateToBank() {
    wx.navigateTo({
      url: '/pages/bank/list'
    })
  },

  // 导航到邀请好友
  navigateToInvite() {
    wx.navigateTo({
      url: '/pages/invite/index'
    })
  },

  // 导航到推广海报
  navigateToPromotion() {
    wx.navigateTo({
      url: '/pages/promotion/poster'
    })
  },

  // 导航到推广二维码
  navigateToQrcode() {
    wx.navigateTo({
      url: '/pages/promotion/qrcode'
    })
  },

  // 导航到收益明细
  navigateToIncome() {
    if (!this.data.isLogin) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      });
      return;
    }

    wx.navigateTo({
      url: '/pages/income/index',
      fail: (err) => {
        console.error('跳转收益明细页面失败:', err);
        wx.showToast({
          title: '跳转失败',
          icon: 'none'
        });
      }
    });
  },

  // 联系客服
  contactService() {
    wx.showToast({
      title: '请添加客服微信',
      icon: 'none'
    })
  },

  // 导航到系统设置
  navigateToSettings() {
    wx.navigateTo({
      url: '/pages/settings/index'
    })
  },

  // 绑定机构
  bindInstitution() {
    if (!this.data.isLogin) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      })
      return
    }

    const userInfo = wx.getStorageSync('userInfo')
    if (!userInfo) {
      wx.showToast({
        title: '获取用户信息失败',
        icon: 'none'
      })
      return
    }

    const businessType = userInfo.bind_business_type
    const queryString = userInfo.bind_query_string
    const commissionType = userInfo.commission_type
    const commissionRatio = userInfo.commission_ratio
    const headSupplierAppid = userInfo.head_supplier_appid

    wx.openBusinessView({
      businessType: businessType,
      queryString: queryString,
      extraData: {
        commissionType: commissionType,
        commissionRatio: commissionRatio,
        headSupplierAppid: headSupplierAppid
      },
      success: (res) => {
        console.log('绑定机构成功', res)
        wx.setStorageSync('bindStatus', 1)
        this.setData({ needBind: false })
      },
      fail: (err) => {
        console.error('绑定机构失败', err)
        wx.showToast({
          title: '绑定失败',
          icon: 'none'
        })
      }
    })
  }
})