import { doLogin, checkNeedLogin, getUserInfo } from './login'

/**
 * 处理小程序启动时的初始化逻辑
 * @param {Object} options 小程序启动参数
 */
export function handleAppLaunch(options) {
  // 检查是否存在邀请码
  if (options && options.query && options.query.invite_code) {
    // 将邀请码存入本地存储
    wx.setStorageSync('invite_code', options.query.invite_code)
  }

  // 初始化用户信息
  initUserInfo()
}

/**
 * 初始化用户信息
 */
async function initUserInfo() {
  try {
    // 如果需要登录，执行登录流程
    if (checkNeedLogin()) {
      await doLogin()
    } else {
      // 已登录，检查是否需要获取用户详细信息
      const bindStatus = wx.getStorageSync('bindStatus')
      if (bindStatus === 1) {
        await getUserInfo()
      }
    }
  } catch (error) {
    console.error('初始化用户信息失败:', error)
  }
}
